from django.shortcuts import render, redirect, get_object_or_404
from django.http import HttpResponse, HttpResponseForbidden
from django.contrib.auth.decorators import login_required
from .models import Color
from django.contrib import messages
from django.db import IntegrityError

@login_required
def colors(request):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        try:
            colors = Color.objects.all()
            return render(request, "inventory/color/colors.html", {'colors': colors})
        except Exception as e:
            messages.error(request, f"An error occurred: {str(e)}")
            return redirect("inventory:colors")
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")

@login_required
def add_color(request):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        if request.method == 'POST':
            try:
                name = request.POST.get('color_name')
                RAL_NUMBER = request.POST.get('RAL_NUMBER')
                added_by = request.user

                if not name:
                    raise ValueError("Color name is required.")

                color = Color(name=name, RAL_NUMBER=RAL_NUMBER, added_by=added_by)
                color.save()

                messages.success(request, 'Color added successfully.')
                return redirect("inventory:colors")
            except ValueError as e:
                messages.error(request, str(e))
            except IntegrityError as e:
                messages.error(request, f"Data integrity error: {str(e)}")
            except Exception as e:
                messages.error(request, f'Error adding color: {str(e)}')
        return render(request, "inventory/color/add_color.html")
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")

@login_required
def edit_color(request, color_id):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        try:
            color = get_object_or_404(Color, id=color_id)
            if request.method == 'POST':
                name = request.POST.get('color_name')
                RAL_NUMBER = request.POST.get('RAL_NUMBER')
                if not name:
                    raise ValueError("Color name is required.")

                color.name = name
                color.RAL_NUMBER = RAL_NUMBER
                color.save()

                messages.success(request, 'Color updated successfully.')
                return redirect("inventory:colors")
            return render(request, "inventory/color/edit_color.html", {'color': color})
        except ValueError as e:
            messages.error(request, str(e))
            return render(request, "inventory/color/edit_color.html", {'color': color})
        except IntegrityError as e:
            messages.error(request, f"Data integrity error: {str(e)}")
            return redirect("inventory:colors")
        except Exception as e:
            messages.error(request, f'Error updating color: {str(e)}')
            return redirect("inventory:colors")
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")

@login_required
def delete_color(request, color_id):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_inventory:
        try:
            color = get_object_or_404(Color, id=color_id)
            color_name = color.name
            color.delete()
            messages.success(request, f"Color '{color_name}' has been deleted successfully.")
        except Exception as e:
            messages.error(request, f'Error deleting color: {str(e)}')
        return redirect("inventory:colors")
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")